@@ -40,6 +40,7 @@ class CLI(cl1.CLI):
 				"    --delete-users user1,user2":"Delete users from the specified group.",
 				"    --force-users user1,user2":"Add the specified users to the group and remove all others.",
 				"--disk-space":"Get the free disk space (linux).",
+				"--size /path/to/file":"Get the size of a file / directory (linux).",
 				"-h / --help":"Show the documentation.",
 			},
 			options={
@@ -51,7 +52,6 @@ class CLI(cl1.CLI):
 
 		#
 	def start(self):
-		syst3m.defaults.check_operating_system(supported=["linux"])
 
 		# clear logs.
 		if not self.arguments_present(['-c']):
@@ -63,6 +63,7 @@ class CLI(cl1.CLI):
 
 		# user.
 		elif self.arguments_present(['--user']):
+			syst3m.defaults.check_operating_system(supported=["linux"])
 
 			# initialize a user object.
 			user = syst3m.User(self.get_argument("--user"))
@@ -107,6 +108,7 @@ class CLI(cl1.CLI):
 
 		# group.
 		elif self.arguments_present(['--group']):
+			syst3m.defaults.check_operating_system(supported=["linux"])
 
 			# initialize a group object.
 			group = syst3m.Group(self.get_argument("--group"))
@@ -159,6 +161,7 @@ class CLI(cl1.CLI):
 
 		# free disk space.
 		elif self.arguments_present(["--disk-space"]):
+			syst3m.defaults.check_operating_system(supported=["linux"])
 			import shutil
 			import math
 			def size(size_bytes):
@@ -172,6 +175,18 @@ class CLI(cl1.CLI):
 			total, used, free = shutil.disk_usage(__file__)
 			print(f"total: {size(total)}, used: {size(used)}, free: {size(free)}")
 
+		# size.
+		elif self.arguments_present(["--size"]):
+			fp = Formats.FilePath(self.get_argument("--size"))
+			if not fp.exists(): 
+				print(f"File path [{fp.path}] does not exist.")
+				sys.exit(1)
+			else:
+				loader = syst3m.console.Loader(f"Retrieving size of {fp.path} ...")
+				size = fp.size()
+				loader.stop()
+				print(f"Size {fp.path}: {size}")
+
 		# invalid.
 		else:  self.invalid()
 
